
/*
 * This class is an interface between the Objective-C GUI
 *	interface and two of the game's key C++ objects,  the Tile Count Manager
 *	and Game Coordinator.
 *
 * It is also the main app controller of this game
 */

extern "C" {
#import	<Cocoa/Cocoa.h>

#import "FarmMJGameInterfaceProtocol.h"

@class FarmMJGameBoardView;
@class FarmMJTileCountView;


#import	"GameEngine.subproj/TileCountManager.h"
#import	"GameEngine.subproj/GameCoordinator.h"
};

@interface FarmMJGameInterface : NSObject <FarmMJGameInterfaceProtocol>
{
    // These variables are outlets. They include the game window and two views that display tiles.
    
    NSWindow *				window;
    id						gameBoardView;
    id 						tileCountView;

    // These are actually C++ objects.

    GameCoordinator *		gameCoordinator;
    TileCountManager *		tileCountManager;

    // This flag is used to prevent draw messages from being sent to the C++ object before
    //	the application has finished initializing.
    
	BOOL			application_initialized;
}

// This is the designated initializer for this class. This method creates
// the Game Coordinator which sets off a chain reaction of object creation.

- (id)init;
- (void)dealloc;

// This object is the delegate of the application. This method completes
// the initialization by creating the Tile Count Manager and Game Coordinator.

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification;

- (void)showInfoPanel:(id)sender;

// Methods from the protocol ... needed so that IB will allow us to draw the connections

- (void)undoClick:(id)sender;
- (void)helpClick:(id)sender;
- (void)againClick:(id)sender;
- (void)newClick:(id)sender;

@end
