// "Legacy" C++ game engine source code...

// This is the base class for tiles. it contains some "bridge" code into the
// AppKit drawing system (like NSImage and NSPoint).

extern "C" {
    #import	<Cocoa/Cocoa.h>
};

// Some tiles need to be shifted by this amount so that a 3d effect can be acheived.

#define	TILE_SHIFT			5
#define	SMALLTILE_SHIFT		2

// Each tile is a square. These constants reflect the pixels high and width of a tile.

#define	TILE_WIDTH				56
#define	TILE_WIDTH_WITH_SHADOW	62
#define	TILE_HEIGHT				64

// For tile count icons...

#define	SMALLTILE_WIDTH			28				
#define	SMALLTILE_HEIGHT		32


#define	TILEIMAGE_ONLY						1
#define	TILEIMAGE_OVER_HIGHLITEDBASE		2
#define	TILEIMAGE_OVER_NORMALBASE			3


class Tile
{
protected:
    // This is a Image object which is loaded with a tiff image and used to display a tile.

    NSImage	*my_tile_image;

    // This member function is called by subclasses to load the tiff file

    void	loadImageFromFile( const char * );

protected:
        // This function does the actual drawing of an image to a point on the board.  All
        //	of the drawImage() routine call this. The first parameter is a point on the
        //	board where the tile is drawn, the second parameter is the composite
        //	operation.

        void	compositeImage( NSPoint, int );

public:
        // This member function is called by the Board View to composite the tile a
        //	a location within the view. (The focus of the view must have been locked
        //	previously.)
        // This member function must be implemented	in the subclasses since game tiles
        //	can be highlighted.
        
        virtual void	drawImage( NSPoint ) = 0;

public:
        Tile( void );
    virtual ~Tile( void );
};

